@@ -119,7 +119,7 @@ knn <- function(algorithm=NA,
   }
 
   if (!identical(query, NA)) {
-    SetParamMat(p, "query", to_matrix(query))
+    SetParamMat(p, "query", to_matrix(query), TRUE)
   }
 
   if (!identical(random_basis, FALSE)) {
@@ -127,7 +127,7 @@ knn <- function(algorithm=NA,
   }
 
   if (!identical(reference, NA)) {
-    SetParamMat(p, "reference", to_matrix(reference))
+    SetParamMat(p, "reference", to_matrix(reference), TRUE)
   }
 
   if (!identical(rho, NA)) {
@@ -147,7 +147,7 @@ knn <- function(algorithm=NA,
   }
 
   if (!identical(true_distances, NA)) {
-    SetParamMat(p, "true_distances", to_matrix(true_distances))
+    SetParamMat(p, "true_distances", to_matrix(true_distances), TRUE)
   }
 
   if (!identical(true_neighbors, NA)) {
